==> smooch_plugin-2.0.1.tar.gz: android/src/main/kotlin/io/skore/smooch_plugin/notification/NotificationTask.kt <==
package io.skore.smooch_plugin.notification

import android.app.NotificationChannel
import android.app.NotificationManager
import android.app.PendingIntent
import android.content.Context
import android.graphics.*
import android.media.RingtoneManager
import android.os.AsyncTask
import android.os.Build
import android.util.Log
import androidx.core.app.NotificationCompat
import io.skore.smooch_plugin.R
import java.io.InputStream
import java.net.URL

class NotificationTask(private val context: Context, private val title: String, private val message: String) : AsyncTask<String, Void, Bitmap?>() {
    private val tag = NotificationTask::class.java.simpleName

    private val channelId = context.getString(R.string.notification_channel_id)
    private val notificationSound = RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION)

    override fun doInBackground(vararg params: String?): Bitmap? {
        val imageUrl = params[0] ?: return null

        val inputStream: InputStream
        var bitmap: Bitmap? = null
        try {
            inputStream = URL(imageUrl).openStream()
            bitmap = BitmapFactory.decodeStream(inputStream)

            bitmap = bitmap?.let {
                val roundedBitmap = Bitmap.createBitmap(it.width, it.height, Bitmap.Config.ARGB_8888)

                val rect = Rect(0, 0, it.width, it.height)
                val paint = Paint().apply {
                    isAntiAlias = true
                }
                Canvas(roundedBitmap).apply {
                    drawARGB(0, 0, 0, 0)

                    val cx = it.width / 2f
                    drawCircle(cx, it.height / 2f, cx, paint)
                    paint.xfermode = PorterDuffXfermode(PorterDuff.Mode.SRC_IN)
                    drawBitmap(it, rect, rect, paint)
                }
                it.recycle()
                roundedBitmap
            }
        } catch (e: Exception) {
            e.printStackTrace()
        } finally {
            return bitmap
        }
    }

//    <intent-filter>
//    <action android:name="android.intent.action.VIEW" />
//
//    <category android:name="android.intent.category.DEFAULT" />
//    <category android:name="android.intent.category.BROWSABLE" />
//
//    <data
//    android:host="chatbot"
//    android:scheme="skore-viavarejo" />
//    </intent-filter>

    private fun setupNotificationIntent(): PendingIntent? {
        val appPackageName = context.getString(R.string.app_package_name)
        val intent = context.packageManager.getLaunchIntentForPackage(appPackageName)?.apply {
            action = "android.intent.action.START_SMOOCH"
//            flags = Intent.FLAG_ACTIVITY_CLEAR_TASK or Intent.FLAG_ACTIVITY_NEW_TASK
//            data = Uri.parse("skore-viavarejo://chatbot")
        } ?: run {
            Log.e(tag, "Could not find package: $appPackageName")
            return null
        }

        return PendingIntent.getActivity(context, 0, intent, PendingIntent.FLAG_ONE_SHOT)
    }

    override fun onPostExecute(result: Bitmap?) {
        super.onPostExecute(result)

        result?.let { icon ->
            Log.d(tag, "Creating notification...")

            val notificationBuilder = NotificationCompat.Builder(context, channelId)
                    .setSmallIcon(R.drawable.ic_comment_dots)
                    .setLargeIcon(icon)
                    .setContentTitle(title)
                    .setContentText(message)
                    .setAutoCancel(true)
                    .setPriority(NotificationCompat.PRIORITY_MAX)
                    .setDefaults(NotificationCompat.DEFAULT_ALL)
                    .setSound(notificationSound)

            setupNotificationIntent()?.let {
                notificationBuilder.setContentIntent(it)
            }

            (context.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager?)?.apply {
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                    val notificationChannel = NotificationChannel(channelId, title, NotificationManager.IMPORTANCE_HIGH).apply {
                        description = message
                        enableLights(true)
                        lightColor = Color.GREEN
                    }
                    createNotificationChannel(notificationChannel)
                }

                notify(0, notificationBuilder.build())
            } ?: Log.e(tag, "Failed to get notification service.")

        } ?: Log.e(tag, "Failed to retrieve notification image.")
    }
}

==> smooch_plugin-2.0.3.tar.gz: android/src/main/kotlin/io/skore/smooch_plugin/notification/NotificationTask.kt <==
package io.skore.smooch_plugin.notification

import android.app.NotificationChannel
import android.app.NotificationManager
import android.app.PendingIntent
import android.content.Context
import android.graphics.*
import android.media.RingtoneManager
import android.os.AsyncTask
import android.os.Build
import android.util.Log
import androidx.core.app.NotificationCompat
import io.skore.smooch_plugin.R
import java.io.InputStream
import java.net.URL

class NotificationTask(private val context: Context, private val title: String, private val message: String) : AsyncTask<String, Void, Bitmap?>() {
    private val tag = NotificationTask::class.java.simpleName

    private val channelId = context.getString(R.string.notification_channel_id)
    private val notificationSound = RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION)

    override fun doInBackground(vararg params: String?): Bitmap? {
        val imageUrl = params[0] ?: return null

        val inputStream: InputStream
        var bitmap: Bitmap? = null
        try {
            inputStream = URL(imageUrl).openStream()
            bitmap = BitmapFactory.decodeStream(inputStream)

            bitmap = bitmap?.let {
                val roundedBitmap = Bitmap.createBitmap(it.width, it.height, Bitmap.Config.ARGB_8888)

                val rect = Rect(0, 0, it.width, it.height)
                val paint = Paint().apply {
                    isAntiAlias = true
                }
                Canvas(roundedBitmap).apply {
                    drawARGB(0, 0, 0, 0)

                    val cx = it.width / 2f
                    drawCircle(cx, it.height / 2f, cx, paint)
                    paint.xfermode = PorterDuffXfermode(PorterDuff.Mode.SRC_IN)
                    drawBitmap(it, rect, rect, paint)
                }
                it.recycle()
                roundedBitmap
            }
        } catch (e: Exception) {
            e.printStackTrace()
        } finally {
            return bitmap
        }
    }

//    <intent-filter>
//    <action android:name="android.intent.action.VIEW" />
//
//    <category android:name="android.intent.category.DEFAULT" />
//    <category android:name="android.intent.category.BROWSABLE" />
//
//    <data
//    android:host="chatbot"
//    android:scheme="skore-viavarejo" />
//    </intent-filter>

    private fun setupNotificationIntent(): PendingIntent? {
        val intent = context.packageManager.getLaunchIntentForPackage(context.packageName)?.apply {
            action = "android.intent.action.START_SMOOCH"
//            flags = Intent.FLAG_ACTIVITY_CLEAR_TASK or Intent.FLAG_ACTIVITY_NEW_TASK
//            data = Uri.parse("skore-viavarejo://chatbot")
        } ?: run {
            Log.e(tag, "Could not find package: ${context.packageManager}")
            return null
        }

        return PendingIntent.getActivity(context, 0, intent, PendingIntent.FLAG_ONE_SHOT)
    }

    override fun onPostExecute(result: Bitmap?) {
        super.onPostExecute(result)

        result?.let { icon ->
            Log.d(tag, "Creating notification...")

            val notificationBuilder = NotificationCompat.Builder(context, channelId)
                    .setSmallIcon(R.drawable.ic_comment_dots)
                    .setLargeIcon(icon)
                    .setContentTitle(title)
                    .setContentText(message)
                    .setAutoCancel(true)
                    .setPriority(NotificationCompat.PRIORITY_MAX)
                    .setDefaults(NotificationCompat.DEFAULT_ALL)
                    .setSound(notificationSound)

            setupNotificationIntent()?.let {
                notificationBuilder.setContentIntent(it)
            }

            (context.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager?)?.apply {
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                    val notificationChannel = NotificationChannel(channelId, title, NotificationManager.IMPORTANCE_HIGH).apply {
                        description = message
                        enableLights(true)
                        lightColor = Color.GREEN
                    }
                    createNotificationChannel(notificationChannel)
                }

                notify(0, notificationBuilder.build())
            } ?: Log.e(tag, "Failed to get notification service.")

        } ?: Log.e(tag, "Failed to retrieve notification image.")
    }
}
